OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "File shares",
    "Downloaded via public link" : "Downloaded via public link",
    "Downloaded by {email}" : "Downloaded by {email}",
    "{file} downloaded via public link" : "{file} downloaded via public link",
    "{email} downloaded {file}" : "{email} downloaded {file}",
    "Shared with group {group}" : "Shared with group {group}",
    "Removed share for group {group}" : "Removed share for group {group}",
    "{actor} shared with group {group}" : "{actor} shared with group {group}",
    "{actor} removed share for group {group}" : "{actor} removed share for group {group}",
    "Share for group {group} expired" : "Share for group {group} expired",
    "You shared {file} with group {group}" : "You shared {file} with group {group}",
    "You removed group {group} from {file}" : "You removed group {group} from {file}",
    "{actor} shared {file} with group {group}" : "{actor} shared {file} with group {group}",
    "{actor} removed group {group} from {file}" : "{actor} removed group {group} from {file}",
    "Share for file {file} with group {group} expired" : "Share for file {file} with group {group} expired",
    "Shared as public link" : "Shared as public link",
    "Removed public link" : "Removed public link",
    "Public link expired" : "Public link expired",
    "{actor} shared as public link" : "{actor} shared as public link",
    "{actor} removed public link" : "{actor} removed public link",
    "Public link of {actor} expired" : "Public link of {actor} expired",
    "You shared {file} as public link" : "You shared {file} as public link",
    "You removed public link for {file}" : "You removed public link for {file}",
    "Public link expired for {file}" : "Public link expired for {file}",
    "{actor} shared {file} as public link" : "{actor} shared {file} as public link",
    "{actor} removed public link for {file}" : "{actor} removed public link for {file}",
    "Public link of {actor} for {file} expired" : "Public link of {actor} for {file} expired",
    "{user} accepted the remote share" : "{user} accepted the remote share",
    "{user} declined the remote share" : "{user} declined the remote share",
    "You received a new remote share {file} from {user}" : "You received a new remote share {file} from {user}",
    "{user} accepted the remote share of {file}" : "{user} accepted the remote share of {file}",
    "{user} declined the remote share of {file}" : "{user} declined the remote share of {file}",
    "{user} unshared {file} from you" : "{user} unshared {file} from you",
    "Shared with {user}" : "Shared with {user}",
    "Removed share for {user}" : "Removed share for {user}",
    "You removed yourself" : "You removed yourself",
    "{actor} removed themselves" : "{actor} removed themselves",
    "{actor} shared with {user}" : "{actor} shared with {user}",
    "{actor} removed share for {user}" : "{actor} removed share for {user}",
    "Shared by {actor}" : "Shared by {actor}",
    "{actor} removed share" : "{actor} removed share",
    "Share for {user} expired" : "Share for {user} expired",
    "Share expired" : "Share expired",
    "You shared {file} with {user}" : "You shared {file} with {user}",
    "You removed {user} from {file}" : "You removed {user} from {file}",
    "You removed yourself from {file}" : "You removed yourself from {file}",
    "{actor} removed themselves from {file}" : "{actor} removed themselves from {file}",
    "{actor} shared {file} with {user}" : "{actor} shared {file} with {user}",
    "{actor} removed {user} from {file}" : "{actor} removed {user} from {file}",
    "{actor} shared {file} with you" : "{actor} shared {file} with you",
    "{actor} removed you from the share named {file}" : "{actor} removed you from the share named {file}",
    "Share for file {file} with {user} expired" : "Share for file {file} with {user} expired",
    "Share for file {file} expired" : "Share for file {file} expired",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "A file or folder shared by mail or by public link was <strong>downloaded</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "A file or folder was shared from <strong>another server</strong>",
    "Sharing" : "Sharing",
    "A file or folder has been <strong>shared</strong>" : "A file or folder has been <strong>shared</strong>",
    "Shared link" : "Shared link",
    "Wrong share ID, share does not exist" : "Wrong share ID, share does not exist",
    "Could not delete share" : "Could not delete share",
    "Please specify a file or folder path" : "Please specify a file or folder path",
    "Wrong path, file/folder does not exist" : "Wrong path, file/folder does not exist",
    "Could not create share" : "Could not create share",
    "Group sharing is disabled by the administrator" : "Group sharing is disabled by the administrator",
    "Please specify a valid group" : "Please specify a valid group",
    "Public link sharing is disabled by the administrator" : "Public link sharing is disabled by the administrator",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Sharing %1$s failed because the back end does not allow shares from type %2$s",
    "Please specify a valid federated group ID" : "Please specify a valid federated group ID",
    "Sharing %s failed because the back end does not support room shares" : "Sharing %s failed because the back end does not support room shares",
    "Unknown share type" : "Unknown share type",
    "Not a directory" : "Not a directory",
    "Could not lock node" : "Could not lock node",
    "Public upload is only possible for publicly shared folders" : "Public upload is only possible for publicly shared folders",
    "Share must at least have READ or CREATE permissions" : "Share must at least have READ or CREATE permissions",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Share must have READ permission if UPDATE or DELETE permission is set",
    "Public upload disabled by the administrator" : "Public upload disabled by the administrator",
    "Could not lock path" : "Could not lock path",
    "Wrong or no update parameter given" : "Wrong or no update parameter given",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled.",
    "Wrong password" : "Wrong password",
    "shared by %s" : "shared by %s",
    "Download" : "Download",
    "Add to your %s" : "Add to your %s",
    "Direct link" : "Direct link",
    "Share API is disabled" : "Share API is disabled",
    "File sharing" : "File sharing",
    "Share will expire tomorrow" : "Share will expire tomorrow",
    "Your share of {node} will expire tomorrow" : "Your share of {node} will expire tomorrow",
    "You received {share} as a share by {user}" : "You received {share} as a share by {user}",
    "You received {share} to group {group} as a share by {user}" : "You received {share} to group {group} as a share by {user}",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Expiration date" : "Expiration date",
    "Password" : "Password",
    "Link copied" : "Link copied",
    "Share link" : "Share link",
    "Copy" : "Copy",
    "Select" : "Select",
    "Close" : "Close",
    "Error creating the share: {errorMessage}" : "Error creating the share: {errorMessage}",
    "Error creating the share" : "Error creating the share",
    "Cancel" : "Cancel",
    "Continue" : "Continue",
    "Error while toggling options" : "Error while toggling options",
    "Choose a default folder for accepted shares" : "Choose a default folder for accepted shares",
    "Invalid path selected" : "Invalid path selected",
    "Unknown error" : "Unknown error",
    "Set default folder for accepted shares" : "Set default folder for accepted shares",
    "Reset" : "Reset",
    "Reset folder to system default" : "Reset folder to system default",
    "group" : "group",
    "conversation" : "conversation",
    "remote" : "remote",
    "remote group" : "remote group",
    "guest" : "guest",
    "Shared with the group {user} by {owner}" : "Shared with the group {user} by {owner}",
    "Shared with the conversation {user} by {owner}" : "Shared with the conversation {user} by {owner}",
    "Shared with {user} by {owner}" : "Shared with {user} by {owner}",
    "Open Sharing Details" : "Open Sharing Details",
    "Added by {initiator}" : "Added by {initiator}",
    "Via “{folder}”" : "Via “{folder}”",
    "Unshare" : "Unshare",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
    "Copy internal link" : "Copy internal link",
    "Internal link" : "Internal link",
    "{shareWith} by {initiator}" : "{shareWith} by {initiator}",
    "Shared via link by {initiator}" : "Shared via link by {initiator}",
    "Mail share ({label})" : "Mail share ({label})",
    "Share link ({label})" : "Share link ({label})",
    "Share link ({index})" : "Share link ({index})",
    "Actions for \"{title}\"" : "Actions for \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Error, please enter proper password and/or expiration date",
    "Link share created" : "Link share created",
    "Error while creating the share" : "Error while creating the share",
    "Please enter the following required information before creating the share" : "Please enter the following required information before creating the share",
    "Password protection (enforced)" : "Password protection (enforced)",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Create share" : "Create share",
    "Customize link" : "Customize link",
    "Add another link" : "Add another link",
    "Create a new share link" : "Create a new share link",
    "View only" : "View only",
    "Can edit" : "Can edit",
    "Custom permissions" : "Custom permissions",
    "Resharing is not allowed" : "Resharing is not allowed",
    "No elements found." : "No elements found.",
    "Search everywhere" : "მოძებნე ყველგან",
    "Guest" : "Guest",
    "Group" : "Group",
    "Email" : "Email",
    "Talk conversation" : "Talk conversation",
    "Deck board" : "Deck board",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "on {server}",
    "File drop" : "File drop",
    "Terms of service" : "Terms of service",
    "Share with group" : "Share with group",
    "Share in conversation" : "Share in conversation",
    "Share with remote group" : "Share with remote group",
    "Share with guest" : "Share with guest",
    "Update share" : "Update share",
    "Save share" : "Save share",
    "Read" : "Read",
    "Create" : "Create",
    "Edit" : "Edit",
    "Share" : "Share",
    "Delete" : "Delete",
    "Allow upload and editing" : "Allow upload and editing",
    "Allow editing" : "Allow editing",
    "Upload only" : "Upload only",
    "Advanced settings" : "Advanced settings",
    "Share label" : "Share label",
    "Set password" : "Set password",
    "Password expires {passwordExpirationTime}" : "Password expires {passwordExpirationTime}",
    "Password expired" : "Password expired",
    "Video verification" : "Video verification",
    "Expiration date (enforced)" : "Expiration date (enforced)",
    "Set expiration date" : "Set expiration date",
    "Hide download" : "Hide download",
    "Note to recipient" : "Note to recipient",
    "Enter a note for the share recipient" : "Enter a note for the share recipient",
    "Delete share" : "Delete share",
    "Others with access" : "Others with access",
    "Toggle list of others with access to this directory" : "Toggle list of others with access to this directory",
    "Toggle list of others with access to this file" : "Toggle list of others with access to this file",
    "Unable to fetch inherited shares" : "Unable to fetch inherited shares",
    "Shares" : "Shares",
    "Unable to load the shares list" : "Unable to load the shares list",
    "Expires {relativetime}" : "Expires {relativetime}",
    "this share just expired." : "this share just expired.",
    "Shared with you by {owner}" : "Shared with you by {owner}",
    "Link to a file" : "Link to a file",
    "_Accept share_::_Accept shares_" : ["Accept share","Accept shares"],
    "Open in Files" : "Open in Files",
    "_Reject share_::_Reject shares_" : ["Reject share","Reject shares"],
    "_Restore share_::_Restore shares_" : ["Restore share","Restore shares"],
    "Shared" : "Shared",
    "Shared by {ownerDisplayName}" : "Shared by {ownerDisplayName}",
    "Shared with others" : "Shared with others",
    "People" : "People",
    "Overview of shared files." : "Overview of shared files.",
    "No shares" : "No shares",
    "Files and folders you shared or have been shared with you will show up here" : "Files and folders you shared or have been shared with you will show up here",
    "Shared with you" : "Shared with you",
    "List of files that are shared with you." : "List of files that are shared with you.",
    "Nothing shared with you yet" : "Nothing shared with you yet",
    "Files and folders others shared with you will show up here" : "Files and folders others shared with you will show up here",
    "List of files that you shared with others." : "List of files that you shared with others.",
    "Nothing shared yet" : "Nothing shared yet",
    "Files and folders you shared will show up here" : "Files and folders you shared will show up here",
    "Shared by link" : "Shared by link",
    "List of files that are shared by link." : "List of files that are shared by link.",
    "No shared links" : "No shared links",
    "Files and folders you shared by link will show up here" : "Files and folders you shared by link will show up here",
    "Deleted shares" : "Deleted shares",
    "List of shares you left." : "List of shares you left.",
    "No deleted shares" : "No deleted shares",
    "Shares you have left will show up here" : "Shares you have left will show up here",
    "Pending shares" : "Pending shares",
    "List of unapproved shares." : "List of unapproved shares.",
    "No pending shares" : "No pending shares",
    "Shares you have received but not approved will show up here" : "Shares you have received but not approved will show up here",
    "Error updating the share: {errorMessage}" : "Error updating the share: {errorMessage}",
    "Error updating the share" : "Error updating the share",
    "File \"{path}\" has been unshared" : "File \"{path}\" has been unshared",
    "Folder \"{path}\" has been unshared" : "Folder \"{path}\" has been unshared",
    "Password created successfully" : "Password created successfully",
    "Error generating password from password policy" : "Error generating password from password policy",
    "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
    "Shared with you and {circle} by {owner}" : "Shared with you and {circle} by {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Shared with you and the conversation {conversation} by {owner}",
    "Shared with you in a conversation by {owner}" : "Shared with you in a conversation by {owner}",
    "Share not found" : "Share not found",
    "Back to %s" : "Back to %s",
    "Add to your Nextcloud" : "Add to your Nextcloud",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Sharing %s failed because the back end does not support ScienceMesh shares",
    "Copy to clipboard" : "Copy to clipboard",
    "Copy internal link to clipboard" : "Copy internal link to clipboard",
    "Copy public link of \"{title}\" to clipboard" : "Copy public link of \"{title}\" to clipboard",
    "Name or email …" : "Name or email …",
    "Name, email, or Federated Cloud ID …" : "Name, email, or Federated Cloud ID …",
    "Searching …" : "Searching …",
    "Search globally" : "Search globally",
    "Name" : "სახელი",
    "Enter your name" : "Enter your name",
    "Share with {userName}" : "Share with {userName}",
    "Show sharing options" : "Show sharing options",
    "Shared by" : "Shared by",
    "Shared with" : "Shared with",
    "Share note" : "Share note",
    "Show list view" : "Show list view",
    "Show grid view" : "Show grid view",
    "Upload files to %s" : "Upload files to %s",
    "Note" : "Note",
    "Select or drop files" : "Select or drop files",
    "Uploading files" : "Uploading files",
    "Uploaded files:" : "Uploaded files:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "By uploading files, you agree to the %1$sterms of service%2$s."
},
"nplurals=2; plural=(n!=1);");
